# Copyright 2020 The Pigweed Authors
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

# AUTOGENERATED - DO NOT EDIT
# This file contains test data generated by generate_decoding_test_data.cc.
"""Generated test data."""

# pylint: disable=line-too-long
# C++ test case type for tokenized_string_decoding:
#     std::tuple<const char*, std::string_view, std::string_view>


def TestCase(*args):  # pylint: disable=invalid-name
    return tuple(args)


# yapf: disable
TEST_DATA = (

# Simple strings
TestCase("%s", "SFO", b'\x03\x53\x46\x4f'),
TestCase("%s", "KSJC", b'\x04\x4b\x53\x4a\x43'),
TestCase("%s", "", b'\x00'),
TestCase("%5s%s", "   nofun", b'\x02\x6e\x6f\x03\x66\x75\x6e'),
TestCase("%5s%s", "abcdef", b'\x06\x61\x62\x63\x64\x65\x66\x00'),
TestCase("%5s%s", "     abcdef", b'\x00\x06\x61\x62\x63\x64\x65\x66'),
TestCase("%s %-6s%s%s%s", "Intel 80586 toaster oven", b'\x05\x49\x6e\x74\x65\x6c\x05\x38\x30\x35\x38\x36\x07\x74\x6f\x61\x73\x74\x65\x72\x01\x20\x04\x6f\x76\x65\x6e'),
TestCase("%s %-6s%s%s%s", "Apple automatic pencil sharpener", b'\x05\x41\x70\x70\x6c\x65\x09\x61\x75\x74\x6f\x6d\x61\x74\x69\x63\x07\x20\x70\x65\x6e\x63\x69\x6c\x01\x20\x09\x73\x68\x61\x72\x70\x65\x6e\x65\x72'),

# Zero-length strings
TestCase("%s-%s", "so-", b'\x02\x73\x6f\x00'),
TestCase("%s-%s", "-cool", b'\x00\x04\x63\x6f\x6f\x6c'),
TestCase("%s%s%3s%s", "   ", b'\x00\x00\x00\x00'),
TestCase("(%5s)(%2s)(%7s)", "([...])(  )(  [...])", b'\x80\x00\x80'),

# Invalid strings
TestCase("%s", "<[%s ERROR (hi)]>", b'\x03\x68\x69'),
TestCase("%30s", "<[%30s ERROR (hi)]>", b'\x03\x68\x69'),
TestCase("%30s", "<[%30s ERROR (hi)]>", b'\x83\x68\x69'),
TestCase("%s", "<[%s ERROR (yo!)]>", b'\x85\x79\x6f\x21'),
TestCase("%s", "<[%s ERROR]>", b'\x01'),
TestCase("%30s", "<[%30s ERROR]>", b'\x81'),

# Continue after truncated string
TestCase("%s %d %s", "go[...] 2 lunch", b'\x82\x67\x6f\x04\x05\x6c\x75\x6e\x63\x68'),
TestCase("%6s%s%s", " [...]hello[...]there", b'\x80\x85\x68\x65\x6c\x6c\x6f\x05\x74\x68\x65\x72\x65'),

# Floating point
TestCase("%1.1f", "0.0", b'\x00\x00\x00\x00'),
TestCase("%0.5f", "3.14159", b'\xdb\x0f\x49\x40'),

# Character
TestCase("%c", " ", b'\x40'),
TestCase("%c", "$", b'\x48'),
TestCase("%c", "$", b'\x48'),
TestCase("100%c!", "100%!", b'\x4a'),

# Atypical argument types
TestCase("%ju", "99", b'\xc6\x01'),
TestCase("%jd", "99", b'\xc6\x01'),
TestCase("%zu", "8", b'\x10'),
TestCase("%zd", "123", b'\xf6\x01'),
TestCase("%td", "99", b'\xc6\x01'),

# Percent character
TestCase("%%", "%", b''),
TestCase("%%%%%%%%", "%%%%", b'\x61\x62\x63'),
TestCase("whoa%%%%wow%%%%!%%", "whoa%%wow%%!%", b''),
TestCase("This is %d%% effective", "This is 1% effective", b'\x02'),
TestCase("%% is 100%sa%%sign%%%s", "% is 100%a%sign%OK?", b'\x01\x25\x03\x4f\x4b\x3f'),

# Percent character prints after errors
TestCase("%s%%", "-10[...]%", b'\x83\x2d\x31\x30\x00'),
TestCase("%d%% is a good %%", "<[%d MISSING]>% is a good %", b''),

# Various format strings
TestCase("!", "!", b''),
TestCase("%s", "%s", b'\x02\x25\x73'),
TestCase("%s", "hello", b'\x05\x68\x65\x6c\x6c\x6f'),
TestCase("%s%s", "Helloold", b'\x05\x48\x65\x6c\x6c\x6f\x03\x6f\x6c\x64'),
TestCase("%s to the%c%s", "hello to the whirled", b'\x05\x68\x65\x6c\x6c\x6f\x40\x07\x77\x68\x69\x72\x6c\x65\x64'),
TestCase("hello %s %d %d %d", "hello rolled 1 2 3", b'\x06\x72\x6f\x6c\x6c\x65\x64\x02\x04\x06'),
TestCase("", "", b''),
TestCase("This has no specifiers", "This has no specifiers", b''),
TestCase("%s_or_%3s", "hello_or_ hi", b'\x05\x68\x65\x6c\x6c\x6f\x02\x68\x69'),
TestCase("%s_or_%3d", "hello_or_-64", b'\x05\x68\x65\x6c\x6c\x6f\x7f'),
TestCase("%s or hi%c pi=%1.2e", "hello or hi! pi=3.14e+00", b'\x05\x68\x65\x6c\x6c\x6f\x42\xdb\x0f\x49\x40'),
TestCase("Why, %s there. My favorite number is %.2f%c", "Why, hello there. My favorite number is 3.14!", b'\x05\x68\x65\x6c\x6c\x6f\xdb\x0f\x49\x40\x42'),

# Various errors
TestCase("%d", "<[%d MISSING]>", b''),
TestCase("ABC%d123%dabc%dABC", "ABC<[%d MISSING]>123<[%d SKIPPED]>abc<[%d SKIPPED]>ABC", b''),
TestCase("%sXY%+ldxy%a", "Yo![...]XY<[%+ld ERROR]>xy<[%a SKIPPED]>", b'\x83\x59\x6f\x21\x80'),
TestCase("%d", "<[%d MISSING]>", b''),
TestCase("%sXY%+ldxy%a", "Yo![...]XY<[%+ld ERROR]>xy<[%a SKIPPED]>", b'\x83\x59\x6f\x21\x80'),
TestCase("%s%lld%9u", "$[...]<[%lld ERROR]><[%9u SKIPPED]>", b'\x81\x24\x80\x80'),

# Alternate form (#)
TestCase("Hex: %#x", "Hex: 0xbeef", b'\xde\xfb\x05'),
TestCase("Hex: %#08X", "Hex: 0X00FEED", b'\xda\xfb\x07'),

# Random integers
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.210e-013E-01000.3210430.3210430.3210430.321043", b'\xcb\x5f\xa4\x3e\xcb\x5f\xa4\x3e\x00\xcb\x5f\xa4\x3e\xcb\x5f\xa4\x3e\xcb\x5f\xa4\x3e\xcb\x5f\xa4\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.914e-012E-01010.191430.191430.1914300.191430", b'\x4c\x06\x44\x3e\x4c\x06\x44\x3e\x02\x4c\x06\x44\x3e\x4c\x06\x44\x3e\x4c\x06\x44\x3e\x4c\x06\x44\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.087e-011E-01020.108680.108680.1086800.108680", b'\xb5\x93\xde\x3d\xb5\x93\xde\x3d\x04\xb5\x93\xde\x3d\xb5\x93\xde\x3d\xb5\x93\xde\x3d\xb5\x93\xde\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.821e-012E-01030.1821430.1821430.1821430.182143", b'\xd3\x83\x3a\x3e\xd3\x83\x3a\x3e\x06\xd3\x83\x3a\x3e\xd3\x83\x3a\x3e\xd3\x83\x3a\x3e\xd3\x83\x3a\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +4.159e-014E-01040.4159270.4159270.4159270.415927", b'\x56\xf4\xd4\x3e\x56\xf4\xd4\x3e\x08\x56\xf4\xd4\x3e\x56\xf4\xd4\x3e\x56\xf4\xd4\x3e\x56\xf4\xd4\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.019e-019E-01050.9018610.9018610.9018610.901861", b'\x64\xe0\x66\x3f\x64\xe0\x66\x3f\x0a\x64\xe0\x66\x3f\x64\xe0\x66\x3f\x64\xe0\x66\x3f\x64\xe0\x66\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.429e-013E-01060.3429150.3429150.3429150.342915", b'\x8c\x92\xaf\x3e\x8c\x92\xaf\x3e\x0c\x8c\x92\xaf\x3e\x8c\x92\xaf\x3e\x8c\x92\xaf\x3e\x8c\x92\xaf\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +7.011e-017E-01070.7011480.7011480.7011480.701148", b'\x68\x7e\x33\x3f\x68\x7e\x33\x3f\x0e\x68\x7e\x33\x3f\x68\x7e\x33\x3f\x68\x7e\x33\x3f\x68\x7e\x33\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.988e-017E-01080.6988460.6988460.6988460.698846", b'\x96\xe7\x32\x3f\x96\xe7\x32\x3f\x10\x96\xe7\x32\x3f\x96\xe7\x32\x3f\x96\xe7\x32\x3f\x96\xe7\x32\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.383e-018E-01090.8383340.8383340.8383340.838334", b'\x0e\x9d\x56\x3f\x0e\x9d\x56\x3f\x12\x0e\x9d\x56\x3f\x0e\x9d\x56\x3f\x0e\x9d\x56\x3f\x0e\x9d\x56\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.469e-012E-01100.2468540.2468540.2468540.246854", b'\x6b\xc7\x7c\x3e\x6b\xc7\x7c\x3e\x14\x6b\xc7\x7c\x3e\x6b\xc7\x7c\x3e\x6b\xc7\x7c\x3e\x6b\xc7\x7c\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.634e-011E+00110.9634290.9634290.9634290.963429", b'\x4a\xa3\x76\x3f\x4a\xa3\x76\x3f\x16\x4a\xa3\x76\x3f\x4a\xa3\x76\x3f\x4a\xa3\x76\x3f\x4a\xa3\x76\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.454e-013E-01120.3454440.3454440.3454440.345444", b'\xf9\xdd\xb0\x3e\xf9\xdd\xb0\x3e\x18\xf9\xdd\xb0\x3e\xf9\xdd\xb0\x3e\xf9\xdd\xb0\x3e\xf9\xdd\xb0\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.344e-019E-01130.9344260.9344260.9344260.934426", b'\x83\x36\x6f\x3f\x83\x36\x6f\x3f\x1a\x83\x36\x6f\x3f\x83\x36\x6f\x3f\x83\x36\x6f\x3f\x83\x36\x6f\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.880e-014E-01140.3879820.3879820.3879820.387982", b'\x88\xa5\xc6\x3e\x88\xa5\xc6\x3e\x1c\x88\xa5\xc6\x3e\x88\xa5\xc6\x3e\x88\xa5\xc6\x3e\x88\xa5\xc6\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.852e-012E-01150.1851670.1851670.1851670.185167", b'\x7c\x9c\x3d\x3e\x7c\x9c\x3d\x3e\x1e\x7c\x9c\x3d\x3e\x7c\x9c\x3d\x3e\x7c\x9c\x3d\x3e\x7c\x9c\x3d\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.251e-015E-01160.5250540.5250540.5250540.525054", b'\xe9\x69\x06\x3f\xe9\x69\x06\x3f\x20\xe9\x69\x06\x3f\xe9\x69\x06\x3f\xe9\x69\x06\x3f\xe9\x69\x06\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +7.463e-027E-02170.07463110.07463110.0746310.074631", b'\x2a\xd8\x98\x3d\x2a\xd8\x98\x3d\x22\x2a\xd8\x98\x3d\x2a\xd8\x98\x3d\x2a\xd8\x98\x3d\x2a\xd8\x98\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.482e-018E-01180.8481530.8481530.8481530.848153", b'\x88\x20\x59\x3f\x88\x20\x59\x3f\x24\x88\x20\x59\x3f\x88\x20\x59\x3f\x88\x20\x59\x3f\x88\x20\x59\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.654e-012E-01190.1654280.1654280.1654280.165428", b'\xda\x65\x29\x3e\xda\x65\x29\x3e\x26\xda\x65\x29\x3e\xda\x65\x29\x3e\xda\x65\x29\x3e\xda\x65\x29\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.280e-016E-01200.627980.627980.6279800.627980", b'\x47\xc3\x20\x3f\x47\xc3\x20\x3f\x28\x47\xc3\x20\x3f\x47\xc3\x20\x3f\x47\xc3\x20\x3f\x47\xc3\x20\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.176e-016E-01210.6175810.6175810.6175810.617581", b'\xd2\x19\x1e\x3f\xd2\x19\x1e\x3f\x2a\xd2\x19\x1e\x3f\xd2\x19\x1e\x3f\xd2\x19\x1e\x3f\xd2\x19\x1e\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.034e-015E-01220.5033950.5033950.5033950.503395", b'\x85\xde\x00\x3f\x85\xde\x00\x3f\x2c\x85\xde\x00\x3f\x85\xde\x00\x3f\x85\xde\x00\x3f\x85\xde\x00\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.409e-013E-01230.340910.340910.3409100.340910", b'\xcb\x8b\xae\x3e\xcb\x8b\xae\x3e\x2e\xcb\x8b\xae\x3e\xcb\x8b\xae\x3e\xcb\x8b\xae\x3e\xcb\x8b\xae\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.797e-026E-02240.05796970.05796970.0579700.057970", b'\x9d\x71\x6d\x3d\x9d\x71\x6d\x3d\x30\x9d\x71\x6d\x3d\x9d\x71\x6d\x3d\x9d\x71\x6d\x3d\x9d\x71\x6d\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.424e-019E-01250.9423620.9423620.9423620.942362", b'\x9e\x3e\x71\x3f\x9e\x3e\x71\x3f\x32\x9e\x3e\x71\x3f\x9e\x3e\x71\x3f\x9e\x3e\x71\x3f\x9e\x3e\x71\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.129e-016E-01260.6128640.6128640.6128640.612864", b'\xa9\xe4\x1c\x3f\xa9\xe4\x1c\x3f\x34\xa9\xe4\x1c\x3f\xa9\xe4\x1c\x3f\xa9\xe4\x1c\x3f\xa9\xe4\x1c\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.093e-013E-01270.3093140.3093140.3093140.309314", b'\x5e\x5e\x9e\x3e\x5e\x5e\x9e\x3e\x36\x5e\x5e\x9e\x3e\x5e\x5e\x9e\x3e\x5e\x5e\x9e\x3e\x5e\x5e\x9e\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +7.864e-018E-01280.7863820.7863820.7863820.786382", b'\x4e\x50\x49\x3f\x4e\x50\x49\x3f\x38\x4e\x50\x49\x3f\x4e\x50\x49\x3f\x4e\x50\x49\x3f\x4e\x50\x49\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.105e-015E-01290.5104890.5104890.5104890.510489", b'\x65\xaf\x02\x3f\x65\xaf\x02\x3f\x3a\x65\xaf\x02\x3f\x65\xaf\x02\x3f\x65\xaf\x02\x3f\x65\xaf\x02\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.358e-011E-01300.1357620.1357620.1357620.135762", b'\x16\x05\x0b\x3e\x16\x05\x0b\x3e\x3c\x16\x05\x0b\x3e\x16\x05\x0b\x3e\x16\x05\x0b\x3e\x16\x05\x0b\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.879e-011E+00310.987870.987870.9878700.987870", b'\x14\xe5\x7c\x3f\x14\xe5\x7c\x3f\x3e\x14\xe5\x7c\x3f\x14\xe5\x7c\x3f\x14\xe5\x7c\x3f\x14\xe5\x7c\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.994e-012E-01320.1994450.1994450.1994450.199445", b'\x48\x3b\x4c\x3e\x48\x3b\x4c\x3e\x40\x48\x3b\x4c\x3e\x48\x3b\x4c\x3e\x48\x3b\x4c\x3e\x48\x3b\x4c\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.042e-025E-02330.0504220.0504220.0504220.050422", b'\x47\x87\x4e\x3d\x47\x87\x4e\x3d\x42\x47\x87\x4e\x3d\x47\x87\x4e\x3d\x47\x87\x4e\x3d\x47\x87\x4e\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +7.875e-028E-02340.07875130.07875130.0787510.078751", b'\x59\x48\xa1\x3d\x59\x48\xa1\x3d\x44\x59\x48\xa1\x3d\x59\x48\xa1\x3d\x59\x48\xa1\x3d\x59\x48\xa1\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.121e-019E-01350.9120510.9120510.9120510.912051", b'\x2b\x7c\x69\x3f\x2b\x7c\x69\x3f\x46\x2b\x7c\x69\x3f\x2b\x7c\x69\x3f\x2b\x7c\x69\x3f\x2b\x7c\x69\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.001e-011E-01360.1000970.1000970.1000970.100097", b'\xaf\xff\xcc\x3d\xaf\xff\xcc\x3d\x48\xaf\xff\xcc\x3d\xaf\xff\xcc\x3d\xaf\xff\xcc\x3d\xaf\xff\xcc\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.278e-015E-01370.5277510.5277510.5277510.527751", b'\xaa\x1a\x07\x3f\xaa\x1a\x07\x3f\x4a\xaa\x1a\x07\x3f\xaa\x1a\x07\x3f\xaa\x1a\x07\x3f\xaa\x1a\x07\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +7.040e-017E-01380.7039560.7039560.7039560.703956", b'\x76\x36\x34\x3f\x76\x36\x34\x3f\x4c\x76\x36\x34\x3f\x76\x36\x34\x3f\x76\x36\x34\x3f\x76\x36\x34\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.794e-019E-01390.8793580.8793580.8793580.879358", b'\x96\x1d\x61\x3f\x96\x1d\x61\x3f\x4e\x96\x1d\x61\x3f\x96\x1d\x61\x3f\x96\x1d\x61\x3f\x96\x1d\x61\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.455e-012E-01400.2454720.2454720.2454720.245472", b'\x1c\x5d\x7b\x3e\x1c\x5d\x7b\x3e\x50\x1c\x5d\x7b\x3e\x1c\x5d\x7b\x3e\x1c\x5d\x7b\x3e\x1c\x5d\x7b\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.607e-017E-01410.6606620.6606620.6606620.660662", b'\x1f\x21\x29\x3f\x1f\x21\x29\x3f\x52\x1f\x21\x29\x3f\x1f\x21\x29\x3f\x1f\x21\x29\x3f\x1f\x21\x29\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +4.550e-015E-01420.4550340.4550340.4550340.455034", b'\x46\xfa\xe8\x3e\x46\xfa\xe8\x3e\x54\x46\xfa\xe8\x3e\x46\xfa\xe8\x3e\x46\xfa\xe8\x3e\x46\xfa\xe8\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.344e-015E-01430.5343630.5343630.5343630.534363", b'\x0b\xcc\x08\x3f\x0b\xcc\x08\x3f\x56\x0b\xcc\x08\x3f\x0b\xcc\x08\x3f\x0b\xcc\x08\x3f\x0b\xcc\x08\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.146e-012E-01440.2145620.2145620.2145620.214562", b'\x09\xb6\x5b\x3e\x09\xb6\x5b\x3e\x58\x09\xb6\x5b\x3e\x09\xb6\x5b\x3e\x09\xb6\x5b\x3e\x09\xb6\x5b\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.157e-015E-01450.5156980.5156980.5156980.515698", b'\xc3\x04\x04\x3f\xc3\x04\x04\x3f\x5a\xc3\x04\x04\x3f\xc3\x04\x04\x3f\xc3\x04\x04\x3f\xc3\x04\x04\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +7.148e-017E-01460.7147680.7147680.7147680.714768", b'\x0b\xfb\x36\x3f\x0b\xfb\x36\x3f\x5c\x0b\xfb\x36\x3f\x0b\xfb\x36\x3f\x0b\xfb\x36\x3f\x0b\xfb\x36\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.730e-012E-01470.172960.172960.1729600.172960", b'\x62\x1c\x31\x3e\x62\x1c\x31\x3e\x5e\x62\x1c\x31\x3e\x62\x1c\x31\x3e\x62\x1c\x31\x3e\x62\x1c\x31\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.971e-017E-01480.6970990.6970990.6970990.697099", b'\x1b\x75\x32\x3f\x1b\x75\x32\x3f\x60\x1b\x75\x32\x3f\x1b\x75\x32\x3f\x1b\x75\x32\x3f\x1b\x75\x32\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.768e-013E-01490.2767580.2767580.2767580.276758", b'\x31\xb3\x8d\x3e\x31\xb3\x8d\x3e\x62\x31\xb3\x8d\x3e\x31\xb3\x8d\x3e\x31\xb3\x8d\x3e\x31\xb3\x8d\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.734e-012E-01500.1734190.1734190.1734190.173419", b'\xa2\x94\x31\x3e\xa2\x94\x31\x3e\x64\xa2\x94\x31\x3e\xa2\x94\x31\x3e\xa2\x94\x31\x3e\xa2\x94\x31\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.692e-011E+00510.9692260.9692260.9692260.969226", b'\x32\x1f\x78\x3f\x32\x1f\x78\x3f\x66\x32\x1f\x78\x3f\x32\x1f\x78\x3f\x32\x1f\x78\x3f\x32\x1f\x78\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.781e-019E-01520.8781310.8781310.8781310.878131", b'\x35\xcd\x60\x3f\x35\xcd\x60\x3f\x68\x35\xcd\x60\x3f\x35\xcd\x60\x3f\x35\xcd\x60\x3f\x35\xcd\x60\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.279e-013E-01530.3279260.3279260.3279260.327926", b'\xf6\xe5\xa7\x3e\xf6\xe5\xa7\x3e\x6a\xf6\xe5\xa7\x3e\xf6\xe5\xa7\x3e\xf6\xe5\xa7\x3e\xf6\xe5\xa7\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +7.008e-017E-01540.7007780.7007780.7007780.700778", b'\x31\x66\x33\x3f\x31\x66\x33\x3f\x6c\x31\x66\x33\x3f\x31\x66\x33\x3f\x31\x66\x33\x3f\x31\x66\x33\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.957e-011E+00550.9956590.9956590.9956590.995659", b'\x84\xe3\x7e\x3f\x84\xe3\x7e\x3f\x6e\x84\xe3\x7e\x3f\x84\xe3\x7e\x3f\x84\xe3\x7e\x3f\x84\xe3\x7e\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.110e-012E-01560.2110.2110.2110000.211000", b'\x6a\x10\x58\x3e\x6a\x10\x58\x3e\x70\x6a\x10\x58\x3e\x6a\x10\x58\x3e\x6a\x10\x58\x3e\x6a\x10\x58\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.794e-016E-01570.579380.579380.5793800.579380", b'\x3a\x52\x14\x3f\x3a\x52\x14\x3f\x72\x3a\x52\x14\x3f\x3a\x52\x14\x3f\x3a\x52\x14\x3f\x3a\x52\x14\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.704e-014E-01580.3703670.3703670.3703670.370367", b'\xb4\xa0\xbd\x3e\xb4\xa0\xbd\x3e\x74\xb4\xa0\xbd\x3e\xb4\xa0\xbd\x3e\xb4\xa0\xbd\x3e\xb4\xa0\xbd\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +1.978e-012E-01590.1977640.1977640.1977640.197764", b'\x95\x82\x4a\x3e\x95\x82\x4a\x3e\x76\x95\x82\x4a\x3e\x95\x82\x4a\x3e\x95\x82\x4a\x3e\x95\x82\x4a\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.440e-018E-01600.8439990.8439990.8439990.843999", b'\x4d\x10\x58\x3f\x4d\x10\x58\x3f\x78\x4d\x10\x58\x3f\x4d\x10\x58\x3f\x4d\x10\x58\x3f\x4d\x10\x58\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.444e-019E-01610.9443610.9443610.9443610.944361", b'\xa9\xc1\x71\x3f\xa9\xc1\x71\x3f\x7a\xa9\xc1\x71\x3f\xa9\xc1\x71\x3f\xa9\xc1\x71\x3f\xa9\xc1\x71\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +4.393e-024E-02620.04392670.04392670.0439270.043927", b'\x72\xec\x33\x3d\x72\xec\x33\x3d\x7c\x72\xec\x33\x3d\x72\xec\x33\x3d\x72\xec\x33\x3d\x72\xec\x33\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.167e-018E-01630.8167210.8167210.8167210.816721", b'\xa2\x14\x51\x3f\xa2\x14\x51\x3f\x7e\xa2\x14\x51\x3f\xa2\x14\x51\x3f\xa2\x14\x51\x3f\xa2\x14\x51\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.951e-019E-01640.8951460.8951460.8951460.895146", b'\x43\x28\x65\x3f\x43\x28\x65\x3f\x80\x01\x43\x28\x65\x3f\x43\x28\x65\x3f\x43\x28\x65\x3f\x43\x28\x65\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.260e-025E-02650.05259920.05259920.0525990.052599", b'\x38\x72\x57\x3d\x38\x72\x57\x3d\x82\x01\x38\x72\x57\x3d\x38\x72\x57\x3d\x38\x72\x57\x3d\x38\x72\x57\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.882e-019E-01660.8882180.8882180.8882180.888218", b'\x3f\x62\x63\x3f\x3f\x62\x63\x3f\x84\x01\x3f\x62\x63\x3f\x3f\x62\x63\x3f\x3f\x62\x63\x3f\x3f\x62\x63\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +4.788e-015E-01670.4787930.4787930.4787930.478793", b'\x6b\x24\xf5\x3e\x6b\x24\xf5\x3e\x86\x01\x6b\x24\xf5\x3e\x6b\x24\xf5\x3e\x6b\x24\xf5\x3e\x6b\x24\xf5\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.328e-026E-02680.06327770.06327770.0632780.063278", b'\xbb\x97\x81\x3d\xbb\x97\x81\x3d\x88\x01\xbb\x97\x81\x3d\xbb\x97\x81\x3d\xbb\x97\x81\x3d\xbb\x97\x81\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.968e-019E-01690.896790.896790.8967900.896790", b'\x07\x94\x65\x3f\x07\x94\x65\x3f\x8a\x01\x07\x94\x65\x3f\x07\x94\x65\x3f\x07\x94\x65\x3f\x07\x94\x65\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.153e-013E-01700.3153250.3153250.3153250.315325", b'\x4c\x72\xa1\x3e\x4c\x72\xa1\x3e\x8c\x01\x4c\x72\xa1\x3e\x4c\x72\xa1\x3e\x4c\x72\xa1\x3e\x4c\x72\xa1\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.968e-019E-01710.8968210.8968210.8968210.896821", b'\x0b\x96\x65\x3f\x0b\x96\x65\x3f\x8e\x01\x0b\x96\x65\x3f\x0b\x96\x65\x3f\x0b\x96\x65\x3f\x0b\x96\x65\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.917e-019E-01720.8916720.8916720.8916720.891672", b'\x98\x44\x64\x3f\x98\x44\x64\x3f\x90\x01\x98\x44\x64\x3f\x98\x44\x64\x3f\x98\x44\x64\x3f\x98\x44\x64\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.630e-013E-01730.2629920.2629920.2629920.262992", b'\xe0\xa6\x86\x3e\xe0\xa6\x86\x3e\x92\x01\xe0\xa6\x86\x3e\xe0\xa6\x86\x3e\xe0\xa6\x86\x3e\xe0\xa6\x86\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +7.461e-017E-01740.7460720.7460720.7460720.746072", b'\x95\xfe\x3e\x3f\x95\xfe\x3e\x3f\x94\x01\x95\xfe\x3e\x3f\x95\xfe\x3e\x3f\x95\xfe\x3e\x3f\x95\xfe\x3e\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.495e-018E-01750.8495190.8495190.8495190.849519", b'\x0f\x7a\x59\x3f\x0f\x7a\x59\x3f\x96\x01\x0f\x7a\x59\x3f\x0f\x7a\x59\x3f\x0f\x7a\x59\x3f\x0f\x7a\x59\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +4.244e-014E-01760.4244340.4244340.4244340.424434", b'\x63\x4f\xd9\x3e\x63\x4f\xd9\x3e\x98\x01\x63\x4f\xd9\x3e\x63\x4f\xd9\x3e\x63\x4f\xd9\x3e\x63\x4f\xd9\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.790e-011E+00770.9789560.9789560.9789560.978956", b'\xe2\x9c\x7a\x3f\xe2\x9c\x7a\x3f\x9a\x01\xe2\x9c\x7a\x3f\xe2\x9c\x7a\x3f\xe2\x9c\x7a\x3f\xe2\x9c\x7a\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.633e-016E-01780.5632670.5632670.5632670.563267", b'\x48\x32\x10\x3f\x48\x32\x10\x3f\x9c\x01\x48\x32\x10\x3f\x48\x32\x10\x3f\x48\x32\x10\x3f\x48\x32\x10\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.106e-012E-01790.2106230.2106230.2106230.210623", b'\x7d\xad\x57\x3e\x7d\xad\x57\x3e\x9e\x01\x7d\xad\x57\x3e\x7d\xad\x57\x3e\x7d\xad\x57\x3e\x7d\xad\x57\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.172e-013E-01800.3171850.3171850.3171850.317185", b'\x22\x66\xa2\x3e\x22\x66\xa2\x3e\xa0\x01\x22\x66\xa2\x3e\x22\x66\xa2\x3e\x22\x66\xa2\x3e\x22\x66\xa2\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.624e-017E-01810.6623550.6623550.6623550.662355", b'\x18\x90\x29\x3f\x18\x90\x29\x3f\xa2\x01\x18\x90\x29\x3f\x18\x90\x29\x3f\x18\x90\x29\x3f\x18\x90\x29\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.895e-014E-01820.3895240.3895240.3895240.389524", b'\xba\x6f\xc7\x3e\xba\x6f\xc7\x3e\xa4\x01\xba\x6f\xc7\x3e\xba\x6f\xc7\x3e\xba\x6f\xc7\x3e\xba\x6f\xc7\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +9.884e-011E+00830.9883550.9883550.9883550.988355", b'\xcd\x04\x7d\x3f\xcd\x04\x7d\x3f\xa6\x01\xcd\x04\x7d\x3f\xcd\x04\x7d\x3f\xcd\x04\x7d\x3f\xcd\x04\x7d\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.176e-012E-01840.2175680.2175680.2175680.217568", b'\x0b\xca\x5e\x3e\x0b\xca\x5e\x3e\xa8\x01\x0b\xca\x5e\x3e\x0b\xca\x5e\x3e\x0b\xca\x5e\x3e\x0b\xca\x5e\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +4.721e-015E-01850.4721430.4721430.4721430.472143", b'\xbb\xbc\xf1\x3e\xbb\xbc\xf1\x3e\xaa\x01\xbb\xbc\xf1\x3e\xbb\xbc\xf1\x3e\xbb\xbc\xf1\x3e\xbb\xbc\xf1\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.868e-019E-01860.8868160.8868160.8868160.886816", b'\x62\x06\x63\x3f\x62\x06\x63\x3f\xac\x01\x62\x06\x63\x3f\x62\x06\x63\x3f\x62\x06\x63\x3f\x62\x06\x63\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.723e-019E-01870.8722940.8722940.8722940.872294", b'\xa9\x4e\x5f\x3f\xa9\x4e\x5f\x3f\xae\x01\xa9\x4e\x5f\x3f\xa9\x4e\x5f\x3f\xa9\x4e\x5f\x3f\xa9\x4e\x5f\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.230e-025E-02880.05230090.05230090.0523010.052301", b'\x6f\x39\x56\x3d\x6f\x39\x56\x3d\xb0\x01\x6f\x39\x56\x3d\x6f\x39\x56\x3d\x6f\x39\x56\x3d\x6f\x39\x56\x3d'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.598e-017E-01890.6598280.6598280.6598280.659828", b'\x7f\xea\x28\x3f\x7f\xea\x28\x3f\xb2\x01\x7f\xea\x28\x3f\x7f\xea\x28\x3f\x7f\xea\x28\x3f\x7f\xea\x28\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.618e-016E-01900.5617660.5617660.5617660.561766", b'\xe3\xcf\x0f\x3f\xe3\xcf\x0f\x3f\xb4\x01\xe3\xcf\x0f\x3f\xe3\xcf\x0f\x3f\xe3\xcf\x0f\x3f\xe3\xcf\x0f\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.281e-012E-01910.2280650.2280650.2280650.228065", b'\xd6\x89\x69\x3e\xd6\x89\x69\x3e\xb6\x01\xd6\x89\x69\x3e\xd6\x89\x69\x3e\xd6\x89\x69\x3e\xd6\x89\x69\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.881e-013E-01920.2880970.2880970.2880970.288097", b'\x69\x81\x93\x3e\x69\x81\x93\x3e\xb8\x01\x69\x81\x93\x3e\x69\x81\x93\x3e\x69\x81\x93\x3e\x69\x81\x93\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +7.210e-017E-01930.7209650.7209650.7209650.720965", b'\x31\x91\x38\x3f\x31\x91\x38\x3f\xba\x01\x31\x91\x38\x3f\x31\x91\x38\x3f\x31\x91\x38\x3f\x31\x91\x38\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +2.152e-012E-01940.2152470.2152470.2152470.215247", b'\xb3\x69\x5c\x3e\xb3\x69\x5c\x3e\xbc\x01\xb3\x69\x5c\x3e\xb3\x69\x5c\x3e\xb3\x69\x5c\x3e\xb3\x69\x5c\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +5.282e-015E-01950.5281530.5281530.5281530.528153", b'\x0a\x35\x07\x3f\x0a\x35\x07\x3f\xbe\x01\x0a\x35\x07\x3f\x0a\x35\x07\x3f\x0a\x35\x07\x3f\x0a\x35\x07\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +6.896e-017E-01960.689570.689570.6895700.689570", b'\xa6\x87\x30\x3f\xa6\x87\x30\x3f\xc0\x01\xa6\x87\x30\x3f\xa6\x87\x30\x3f\xa6\x87\x30\x3f\xa6\x87\x30\x3f'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.952e-014E-01970.3951650.3951650.3951650.395165", b'\x0e\x53\xca\x3e\x0e\x53\xca\x3e\xc2\x01\x0e\x53\xca\x3e\x0e\x53\xca\x3e\x0e\x53\xca\x3e\x0e\x53\xca\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +3.759e-014E-01980.3759280.3759280.3759280.375928", b'\x96\x79\xc0\x3e\x96\x79\xc0\x3e\xc4\x01\x96\x79\xc0\x3e\x96\x79\xc0\x3e\x96\x79\xc0\x3e\x96\x79\xc0\x3e'),
TestCase("This is a number: %+08.3e%1.0E%02d%g%G%f%-3f", "This is a number: +8.436e-028E-02990.08436450.08436450.0843640.084364", b'\x48\xc7\xac\x3d\x48\xc7\xac\x3d\xc6\x01\x48\xc7\xac\x3d\x48\xc7\xac\x3d\x48\xc7\xac\x3d\x48\xc7\xac\x3d'),
TestCase("%s: %llu %d %c", "0: 646757550612212450 128431401 P", b'\x01\x30\xc4\xab\xd7\xc0\x99\xa4\xdf\xf9\x11\xd2\xd4\xbd\x7a\xa0\x01'),
TestCase("%s: %llu %d %c", "1: 5294527771240555016 1496480504 	", b'\x01\x31\x90\x88\xdf\xa3\x9a\xbd\xf8\xf9\x92\x01\xf0\xeb\x93\x93\x0b\x12'),
TestCase("%s: %llu %d %c", "2: 4061389961487213535 1555570883 >", b'\x01\x32\xbe\x8f\xc3\xcc\xdb\xa9\xfa\xdc\x70\x86\x83\xc1\xcb\x0b\x7c'),
TestCase("%s: %llu %d %c", "3: 7083829078452288754 1162540900 d", b'\x01\x33\xe4\xf3\xd9\xeb\xfb\xc0\xe8\xce\xc4\x01\xc8\xdd\xd7\xd4\x08\xc8\x01'),
TestCase("%s: %llu %d %c", "4: 4002626457632111277 1471392205 <", b'\x01\x34\xda\xea\xef\xfb\xcd\xe3\x97\x8c\x6f\x9a\xa7\x9d\xfb\x0a\x78'),
TestCase("%s: %llu %d %c", "5: 3705575452837642392 999262596 K", b'\x01\x35\xb0\x82\xdc\xac\xb9\xcf\xec\xec\x66\x88\xa6\xfc\xb8\x07\x96\x01'),
TestCase("%s: %llu %d %c", "6: 6557245727662973594 896373144 4", b'\x01\x36\xb4\x8a\xe5\xe4\xeb\x8f\x82\x80\xb6\x01\xb0\xc6\xec\xd6\x06\x68'),
TestCase("%s: %llu %d %c", "7: 5454275499512896944 1226045852 z", b'\x01\x37\xe0\xf6\xa8\xf9\xe6\xaa\xbd\xb1\x97\x01\xb8\xe6\x9f\x91\x09\xf4\x01'),
TestCase("%s: %llu %d %c", "8: 9044083069173435164 1766891050 '", b'\x01\x38\xb8\xac\xa8\x93\xc8\xe8\x84\x83\xfb\x01\xd4\xf8\x84\x95\x0d\x4e'),
TestCase("%s: %llu %d %c", "9: 5076270483973408909 977144804 ^", b'\x01\x39\x9a\xa2\xc8\xd0\x84\xc7\xc4\xf2\x8c\x01\xc8\xaf\xf0\xa3\x07\xbc\x01'),
TestCase("%s: %llu %d %c", "10: 6514086955327654755 2144124549 D", b'\x02\x31\x30\xc6\xad\xfc\x84\xd4\xe4\xd7\xe6\xb4\x01\x8a\xfa\xe5\xfc\x0f\x88\x01'),
TestCase("%s: %llu %d %c", "11: 4628058100229254151 1281962171  ", b'\x02\x31\x31\x8e\xb0\xc5\x80\xcb\x94\x95\xba\x80\x01\xf6\xc2\xc9\xc6\x09\x40'),
TestCase("%s: %llu %d %c", "12: 1076793340331741575 2057242876 Q", b'\x02\x31\x32\x8e\xc6\xd6\xaf\xd0\xf5\xc4\xf1\x1d\xf8\xa3\xf8\xa9\x0f\xa2\x01'),
TestCase("%s: %llu %d %c", "13: 5264779051526567427 890694850 .", b'\x02\x31\x33\x86\xd8\xc5\xb2\xe8\xa9\xa0\x90\x92\x01\x84\xb3\xb7\xd1\x06\x5c'),
TestCase("%s: %llu %d %c", "14: 6197432947465793532 1477386409 L", b'\x02\x31\x34\xf8\xbf\x81\x90\xc5\x9b\xda\x81\xac\x01\xd2\x82\xf9\x80\x0b\x98\x01'),
TestCase("%s: %llu %d %c", "15: 1939578830432974807 487012735 A", b'\x02\x31\x35\xae\xdf\x99\x9d\xf0\xaa\xe2\xea\x35\xfe\xe5\xb9\xd0\x03\x82\x01'),
TestCase("%s: %llu %d %c", "16: 4252410814844357301 2016407074 <", b'\x02\x31\x36\xea\xaa\x9e\x9d\xe3\xc6\xcc\x83\x76\xc4\xb8\xff\x82\x0f\x78'),
TestCase("%s: %llu %d %c", "17: 4095317955084962012 897441415 F", b'\x02\x31\x37\xb8\xa3\xf2\xb1\xee\xfe\xbe\xd5\x71\x8e\xfa\xee\xd7\x06\x8c\x01'),
TestCase("%s: %llu %d %c", "18: 8433702361086030159 2131660974 ~", b'\x02\x31\x38\x9e\xc5\xbf\xde\xa3\xe7\xc3\x8a\xea\x01\xdc\xc2\xf4\xf0\x0f\xfc\x01'),
TestCase("%s: %llu %d %c", "19: 5127196966915280688 1045937034 e", b'\x02\x31\x39\xe0\xbc\x90\xa7\xbe\x9e\xbb\xa7\x8e\x01\x94\xee\xbd\xe5\x07\xca\x01'),
TestCase("%s: %llu %d %c", "20: 8259453203008866922 1179139938 A", b'\x02\x32\x30\xd4\xa9\xf2\xc4\xaf\xbb\xbc\x9f\xe5\x01\xc4\xfd\xc1\xe4\x08\x82\x01'),
TestCase("%s: %llu %d %c", "21: 8275937406817640763 443381940 G", b'\x02\x32\x31\xf6\x84\xdd\xcb\xa8\xce\x84\xda\xe5\x01\xe8\xe2\xeb\xa6\x03\x8e\x01'),
TestCase("%s: %llu %d %c", "22: 997754361730893686 1007730161 e", b'\x02\x32\x32\xec\x9d\x88\x81\xc8\x93\xde\xd8\x1b\xe2\xf7\x85\xc1\x07\xca\x01'),
TestCase("%s: %llu %d %c", "23: 256781249510239018 1812585134 !", b'\x02\x32\x33\xd4\xac\xcf\xa0\xf3\xcb\xa2\x90\x07\xdc\xea\xce\xc0\x0d\x42'),
TestCase("%s: %llu %d %c", "24: 2332871340892345868 1139696535 2", b'\x02\x32\x34\x98\xd8\x9e\xc9\xfb\x87\x83\xe0\x40\xae\x8e\xf3\xbe\x08\x64'),
TestCase("%s: %llu %d %c", "25: 1987972021100915124 725058015 q", b'\x02\x32\x35\xe8\xa6\x95\xd2\xa7\x81\xd9\x96\x37\xbe\x87\xbc\xb3\x05\xe2\x01'),
TestCase("%s: %llu %d %c", "26: 5784824274936856659 746840193 y", b'\x02\x32\x36\xa6\x81\xd8\xba\xeb\xc1\xe9\xc7\xa0\x01\x82\x82\x9f\xc8\x05\xf2\x01'),
TestCase("%s: %llu %d %c", "27: 1164916386415315063 68230794 $", b'\x02\x32\x37\xee\xa1\x88\xd5\x81\xd2\xce\xaa\x20\x94\xfa\x88\x41\x48'),
TestCase("%s: %llu %d %c", "28: 3140932642079254647 430103045 r", b'\x02\x32\x38\xee\xa1\x81\xa9\x97\xe6\xea\x96\x57\x8a\xe8\x96\x9a\x03\xe4\x01'),
TestCase("%s: %llu %d %c", "29: 7940449326902609449 1006905623 N", b'\x02\x32\x39\xd2\x98\xa8\xf0\xf5\xa5\x92\xb2\xdc\x01\xae\xa4\xa1\xc0\x07\x9c\x01'),
TestCase("%s: %llu %d %c", "30: 5240496025593009868 112523603 (", b'\x02\x33\x30\x98\xdb\x8a\xc5\xd6\xd7\xfd\xb9\x91\x01\xa6\xe5\xa7\x6b\x50'),
TestCase("%s: %llu %d %c", "31: 5038839083535780307 849780316 ~", b'\x02\x33\x31\xa6\xa7\x8a\xe8\xe2\xdc\xc6\xed\x8b\x01\xb8\xf9\xb4\xaa\x06\xfc\x01'),
TestCase("%s: %llu %d %c", "32: 3630797309549363234 1877081269 B", b'\x02\x33\x32\xc4\x80\x92\xf2\xd1\xba\x97\xe3\x64\xea\xf2\x8f\xfe\x0d\x84\x01'),
TestCase("%s: %llu %d %c", "33: 3467724524658884800 1223515015 (", b'\x02\x33\x33\x80\x83\xa0\xf3\xa2\xc5\xea\x9f\x60\x8e\xee\xea\x8e\x09\x50'),
TestCase("%s: %llu %d %c", "34: 7712429266319135356 1217500709 l", b'\x02\x33\x34\xf8\xc9\xba\xe4\xc6\xe3\x86\x88\xd6\x01\xca\xd8\x8c\x89\x09\xd8\x01'),
TestCase("%s: %llu %d %c", "35: 3291981441856444913 1855334785 y", b'\x02\x33\x35\xe2\xe7\xc0\x90\xc0\xeb\xbb\xaf\x5b\x82\xa6\xb1\xe9\x0d\xf2\x01'),
TestCase("%s: %llu %d %c", "36: 4919847686728209916 715097219 :", b'\x02\x33\x36\xf8\xd7\xb2\xc7\xf2\xd9\xe7\xc6\x88\x01\x86\x92\xfc\xa9\x05\x74'),
TestCase("%s: %llu %d %c", "37: 6001314382948090489 1275341105 ]", b'\x02\x33\x37\xf2\x89\x82\xd1\xd1\xe8\xf9\xc8\xa6\x01\xe2\xa4\xa1\xc0\x09\xba\x01'),
TestCase("%s: %llu %d %c", "38: 3119268858057174477 692013498 2", b'\x02\x33\x38\x9a\xb7\xfd\xb6\xfe\x9f\xef\xc9\x56\xf4\xa6\xfa\x93\x05\x64'),
TestCase("%s: %llu %d %c", "39: 3141952960809904282 1723961557 I", b'\x02\x33\x39\xb4\xa2\xfd\xa0\xc6\xe4\xba\x9a\x57\xaa\xc3\x8c\xec\x0c\x92\x01'),
TestCase("%s: %llu %d %c", "40: 3962329461475475834 2013070724 s", b'\x02\x34\x30\xf4\x85\xfc\xa4\xdc\xe9\x82\xfd\x6d\x88\x96\xe8\xff\x0e\xe6\x01'),
TestCase("%s: %llu %d %c", "41: 6705183005166907218 2031346987 f", b'\x02\x34\x31\xa4\xbd\xad\x8f\xdd\x9a\xcc\x8d\xba\x01\xd6\x94\x9f\x91\x0f\xcc\x01'),
TestCase("%s: %llu %d %c", "42: 5275577307833715720 1461891095 B", b'\x02\x34\x32\x90\xb0\xd2\xa8\x87\xe7\xce\xb6\x92\x01\xae\xc0\x95\xf2\x0a\x84\x01'),
TestCase("%s: %llu %d %c", "43: 4999233507689781945 991216024 |", b'\x02\x34\x33\xf2\xea\xa2\xf1\xeb\x98\xec\xe0\x8a\x01\xb0\x86\xa6\xb1\x07\xf8\x01'),
TestCase("%s: %llu %d %c", "44: 2788213596089450528 1662775838 '", b'\x02\x34\x34\xc0\x80\x9c\x8d\xc7\xdf\xdc\xb1\x4d\xbc\xc8\xdf\xb1\x0c\x4e'),
TestCase("%s: %llu %d %c", "45: 1507235571856201971 690944234 &", b'\x02\x34\x35\xe6\xe3\x92\xd5\x8a\xb1\xe3\xea\x29\xd4\xe3\xf7\x92\x05\x4c'),
TestCase("%s: %llu %d %c", "46: 8120818212305491728 1991854726 U", b'\x02\x34\x36\xa0\xdc\xee\xdf\xeb\xc8\xf8\xb2\xe1\x01\x8c\xaa\xca\xeb\x0e\xaa\x01'),
TestCase("%s: %llu %d %c", "47: 850107129610567275 826171792 A", b'\x02\x34\x37\xd6\xf9\xb7\x97\xc5\xfb\x97\xcc\x17\xa0\x86\xf3\x93\x06\x82\x01'),
TestCase("%s: %llu %d %c", "48: 3619717899166040237 5848102 [", b'\x02\x34\x38\xda\x82\xd2\xee\x89\x90\xe9\xbb\x64\xcc\xf0\xc9\x05\xb6\x01'),
TestCase("%s: %llu %d %c", "49: 4766478454387430761 938318292 '", b'\x02\x34\x39\xd2\xd5\x86\xf5\xcf\xb9\xf7\xa5\x84\x01\xa8\xe7\xec\xfe\x06\x4e'),
TestCase("%s: %llu %d %c", "50: 7278057998974406311 2037680599 q", b'\x02\x35\x30\xce\xba\xfa\xb8\x8e\xcc\xed\x80\xca\x01\xae\xa7\xa4\x97\x0f\xe2\x01'),
TestCase("%s: %llu %d %c", "51: 3273441488341945355 1215440713 U", b'\x02\x35\x31\x96\xb0\xae\x9a\x96\xec\xcc\xed\x5a\x92\x9d\x91\x87\x09\xaa\x01'),
TestCase("%s: %llu %d %c", "52: 1352148195246416250 1195236094 E", b'\x02\x35\x32\xf4\x85\xc9\xd5\xd3\xe7\xe5\xc3\x25\xfc\xeb\xee\xf3\x08\x8a\x01'),
TestCase("%s: %llu %d %c", "53: 1676322249364352341 1204736997 m", b'\x02\x35\x33\xaa\xb5\x91\xa7\x89\x8d\xbf\xc3\x2e\xca\xcf\xf6\xfc\x08\xda\x01'),
TestCase("%s: %llu %d %c", "54: 2333671424671038513 1489186116 [", b'\x02\x35\x34\xe2\xf0\xf9\x9f\xfc\xf2\xee\xe2\x40\x88\xb5\x99\x8c\x0b\xb6\x01'),
TestCase("%s: %llu %d %c", "55: 4281900075145433102 1885273938 ~", b'\x02\x35\x35\x9c\xc0\x98\xec\xd1\xdb\xae\xec\x76\xa4\xfd\xf7\x85\x0e\xfc\x01'),
TestCase("%s: %llu %d %c", "56: 1034989118514460270 670362370 O", b'\x02\x35\x36\xdc\xd9\x97\xb7\xd4\xc7\x82\xdd\x1c\x84\xac\xa7\xff\x04\x9e\x01'),
TestCase("%s: %llu %d %c", "57: 2474224803315291647 852899224 h", b'\x02\x35\x37\xfe\xd7\x8c\x81\xb0\x96\x9b\xd6\x44\xb0\xd6\xb1\xad\x06\xd0\x01'),
TestCase("%s: %llu %d %c", "58: 6086297047179889204 792444130 G", b'\x02\x35\x38\xe8\xa8\xd4\xea\xde\xba\xef\xf6\xa8\x01\xc4\xf3\xdd\xf3\x05\x8e\x01'),
TestCase("%s: %llu %d %c", "59: 4129732865765686804 1968869102 U", b'\x02\x35\x39\xa8\xf8\xc1\x93\xa8\x8a\xe1\xcf\x72\xdc\xbb\xd4\xd5\x0e\xaa\x01'),
TestCase("%s: %llu %d %c", "60: 8297459921109698914 642375500 A", b'\x02\x36\x30\xc4\xa5\xc6\xfc\xc3\xf5\xbf\xa6\xe6\x01\x98\xfd\xce\xe4\x04\x82\x01'),
TestCase("%s: %llu %d %c", "61: 8848352886883606505 278420198 )", b'\x02\x36\x31\xd2\xff\xfe\xdf\xbd\x84\xd5\xcb\xf5\x01\xcc\xeb\xc2\x89\x02\x52'),
TestCase("%s: %llu %d %c", "62: 639367729021931858 519678154 p", b'\x02\x36\x32\xa4\xc5\x9a\x93\xfc\xe3\xbe\xdf\x11\x94\xa3\xcd\xef\x03\xe0\x01'),
TestCase("%s: %llu %d %c", "63: 4168177859746898377 293410050 {", b'\x02\x36\x33\x92\x87\xe5\xad\xbe\xeb\xab\xd8\x73\x84\xd4\xe8\x97\x02\xf6\x01'),
TestCase("%s: %llu %d %c", "64: 8933020158994285890 1727299316 n", b'\x02\x36\x34\x84\x95\x90\xc4\xac\xa0\xbb\xf8\xf7\x01\xe8\xfb\xa3\xef\x0c\xdc\x01'),
TestCase("%s: %llu %d %c", "65: 2904831533300168615 1786519136 V", b'\x02\x36\x35\xce\xde\xad\xab\xf3\xb8\x84\xd0\x50\xc0\xf9\xe0\xa7\x0d\xac\x01'),
TestCase("%s: %llu %d %c", "66: 625118648746706096 1778893413 Q", b'\x02\x36\x36\xe0\x92\xa8\x90\xab\x86\xef\xac\x11\xca\x89\xbe\xa0\x0d\xa2\x01'),
TestCase("%s: %llu %d %c", "67: 3317249430279903162 738620162 '", b'\x02\x36\x37\xf4\xde\x9a\xb3\x80\xb2\x9e\x89\x5c\x84\xcc\xb3\xc0\x05\x4e'),
TestCase("%s: %llu %d %c", "68: 2529759202900350655 1638933594 =", b'\x02\x36\x38\xfe\xda\xb4\x82\xf0\xa5\xc1\x9b\x46\xb4\x91\x81\x9b\x0c\x7a'),
TestCase("%s: %llu %d %c", "69: 4162847733300040370 641234596 `", b'\x02\x36\x39\xe4\xca\x9c\xd6\xa5\xfd\xb3\xc5\x73\xc8\xda\xc3\xe3\x04\xc0\x01'),
TestCase("%s: %llu %d %c", "70: 8048952107112912959 1411687739 _", b'\x02\x37\x30\xfe\xe0\xc6\xe9\xfa\xd2\xcf\xb3\xdf\x01\xf6\x94\xa5\xc2\x0a\xbe\x01'),
TestCase("%s: %llu %d %c", "71: 1860779983819210237 1258094565 Q", b'\x02\x37\x31\xfa\xf7\x9b\xcb\xaa\xe2\xe8\xd2\x33\xca\xff\xe7\xaf\x09\xa2\x01'),
TestCase("%s: %llu %d %c", "72: 133586295505940516 1385623828 t", b'\x02\x37\x32\xc8\xc0\xef\xa7\xe5\x81\xcc\xda\x03\xa8\xc4\xb7\xa9\x0a\xe8\x01'),
TestCase("%s: %llu %d %c", "73: 476590412526583632 1426152233 	", b'\x02\x37\x33\xa0\xfd\x87\xa0\x90\x9d\x98\x9d\x0d\xd2\xec\x8a\xd0\x0a\x12'),
TestCase("%s: %llu %d %c", "74: 7182329075191030773 870570930 }", b'\x02\x37\x34\xea\x8f\xc5\xab\xb0\x8f\xe1\xac\xc7\x01\xe4\xee\x9e\xbe\x06\xfa\x01'),
TestCase("%s: %llu %d %c", "75: 6781911602451840052 1186936344 Z", b'\x02\x37\x35\xe8\xf0\xef\xa3\xf3\xaa\x98\x9e\xbc\x01\xb0\xd8\xf9\xeb\x08\xb4\x01'),
TestCase("%s: %llu %d %c", "76: 2755779697069684711 1068026786 W", b'\x02\x37\x36\xce\xdf\x93\xb1\x94\xc2\xbf\xbe\x4c\xc4\xae\xc6\xfa\x07\xae\x01'),
TestCase("%s: %llu %d %c", "77: 7605101363071432517 182922063 S", b'\x02\x37\x37\x8a\xdd\xb1\xab\xad\xd9\xdf\x8a\xd3\x01\x9e\xad\xb9\xae\x01\xa6\x01'),
TestCase("%s: %llu %d %c", "78: 8440954818933111077 809999951 +", b'\x02\x37\x38\xca\xe4\x89\xba\xf1\xeb\xa5\xa4\xea\x01\x9e\xf9\xbc\x84\x06\x56'),
TestCase("%s: %llu %d %c", "79: 177390365453428882 521931632 *", b'\x02\x37\x39\xa4\xa2\xed\xf6\x9e\xe6\x9b\xf6\x04\xe0\xad\xe0\xf1\x03\x54'),
TestCase("%s: %llu %d %c", "80: 2690515256289614444 1230288283 #", b'\x02\x38\x30\xd8\xe9\xca\x9e\xdc\xd7\xd0\xd6\x4a\xb6\xd6\xa5\x95\x09\x46'),
TestCase("%s: %llu %d %c", "81: 7345613454774364586 1636244573 z", b'\x02\x38\x31\xd4\xa6\xbf\xd2\x96\xa1\xee\xf0\xcb\x01\xba\xf1\xb8\x98\x0c\xf4\x01'),
TestCase("%s: %llu %d %c", "82: 6370586723714568954 1353978889 X", b'\x02\x38\x32\xf4\xcb\x9c\xdd\xea\xb7\xef\xe8\xb0\x01\x92\xd0\xa0\x8b\x0a\xb0\x01'),
TestCase("%s: %llu %d %c", "83: 731720363738568228 1838212903 J", b'\x02\x38\x33\xc8\xd8\xf4\xb8\xe8\xf2\xcb\xa7\x14\xce\x9c\x87\xd9\x0d\x94\x01'),
TestCase("%s: %llu %d %c", "84: 9161537274294991160 1309917278 u", b'\x02\x38\x34\xf0\xe4\xd3\xed\x8d\xe7\xa8\xa4\xfe\x01\xbc\x81\x9e\xe1\x09\xea\x01'),
TestCase("%s: %llu %d %c", "85: 1558715097695343451 97413929 Z", b'\x02\x38\x35\xb6\xcd\xda\x82\xef\xc7\xd5\xa1\x2b\xd2\xac\xf3\x5c\xb4\x01'),
TestCase("%s: %llu %d %c", "86: 366808135709449019 1760066788 z", b'\x02\x38\x36\xf6\xec\xfa\xda\xca\x83\x95\x97\x0a\xc8\xf3\xc3\x8e\x0d\xf4\x01'),
TestCase("%s: %llu %d %c", "87: 891656539731055874 742154760 1", b'\x02\x38\x37\x84\xd4\x96\x85\xc2\xb9\xe6\xdf\x18\x90\x88\xe3\xc3\x05\x62'),
TestCase("%s: %llu %d %c", "88: 3732114429930137548 1005229045 2", b'\x02\x38\x38\x98\x9f\xc3\x91\x9d\x93\x91\xcb\x67\xea\xcf\xd4\xbe\x07\x64'),
TestCase("%s: %llu %d %c", "89: 8113837181842537067 1082098316 G", b'\x02\x38\x39\xd6\xe9\xa5\xd1\xb1\xfb\x91\x9a\xe1\x01\x98\x8a\xfc\x87\x08\x8e\x01'),
TestCase("%s: %llu %d %c", "90: 2770024080011047550 1330821140 N", b'\x02\x39\x30\xfc\xc9\xb1\xc5\xaf\x8e\x8d\xf1\x4c\xa8\xe0\x95\xf5\x09\x9c\x01'),
TestCase("%s: %llu %d %c", "91: 4697198541546045125 2128296134 x", b'\x02\x39\x31\x8a\xfb\xad\xc5\xf9\xcb\xe6\xaf\x82\x01\x8c\xe3\xd9\xed\x0f\xf0\x01'),
TestCase("%s: %llu %d %c", "92: 1018100739973888361 570654735 w", b'\x02\x39\x32\xd2\xe5\xa5\xfb\xd2\xce\x82\xa1\x1c\x9e\x80\x9c\xa0\x04\xee\x01'),
TestCase("%s: %llu %d %c", "93: 4859753067646279323 676264182 W", b'\x02\x39\x33\xb6\xfa\xde\xd2\xd7\xea\xa7\xf1\x86\x01\xec\xe3\xf7\x84\x05\xae\x01'),
TestCase("%s: %llu %d %c", "94: 549670438443165922 132670573 t", b'\x02\x39\x34\xc4\xa3\x81\xaf\xbf\x96\xe9\xa0\x0f\xda\x91\xc3\x7e\xe8\x01'),
TestCase("%s: %llu %d %c", "95: 3444356383434812300 501045255 2", b'\x02\x39\x35\x98\xae\xd9\xa7\xb7\xf8\xe7\xcc\x5f\x8e\xe0\xea\xdd\x03\x64'),
TestCase("%s: %llu %d %c", "96: 2011546512680833085 1077631988 Z", b'\x02\x39\x36\xfa\xc0\xa2\x98\xa9\xb9\xb9\xea\x37\xe8\xef\xda\x83\x08\xb4\x01'),
TestCase("%s: %llu %d %c", "97: 4692262078416922470 1829700092 '", b'\x02\x39\x37\xcc\x9d\x9d\x91\xfd\xdf\xa1\x9e\x82\x01\xf8\x87\xf8\xd0\x0d\x4e'),
TestCase("%s: %llu %d %c", "98: 4919691286333696629 1322133483 l", b'\x02\x39\x38\xea\xa9\x89\xe8\x98\xca\xa0\xc6\x88\x01\xd6\x9f\xf1\xec\x09\xd8\x01'),
TestCase("%s: %llu %d %c", "99: 1241746909443220722 1232171669 L", b'\x02\x39\x39\xe4\x93\xeb\xe4\x85\x8f\xc9\xbb\x22\xaa\xca\x8b\x97\x09\x98\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "0: 1941514050836526867 0x      21293775377EEBB901 101", b'\x01\x30\xa6\xdc\xd3\xe8\xc3\xaf\xd2\xf1\x35\x82\xe4\xdd\xee\x0f\x82\xe4\xdd\xee\x0f\xca\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "1: 3509957387132194637 0x      19171154647244DC48 33", b'\x01\x31\x9a\xbd\xae\xcc\xb4\xe9\xef\xb5\x61\x90\xf1\xa6\xa4\x0e\x90\xf1\xa6\xa4\x0e\x42'),
TestCase("%s: %lld 0x%16u%08X %d", "2: 8024983545482782384 0x      15299301625B30E1B2 46", b'\x01\x32\xe0\x9a\xd9\xcd\x86\x81\xbc\xde\xde\x01\xe4\x86\x87\xb3\x0b\xe4\x86\x87\xb3\x0b\x5c'),
TestCase("%s: %lld 0x%16u%08X %d", "3: 5058360797369425151 0x      10725304213FED83F5 104", b'\x01\x33\xfe\xf3\xba\x8f\x89\x96\xf4\xb2\x8c\x01\xea\x8f\xec\xfe\x07\xea\x8f\xec\xfe\x07\xd0\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "4: 6529118911438932678 0x       9786230773A549A65 105", b'\x01\x34\x8c\xab\xd2\xc9\xd4\xc3\x8b\x9c\xb5\x01\xca\xe9\xa4\xa5\x07\xca\xe9\xa4\xa5\x07\xd2\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "5: 4463425652718897265 0x        17497759010AFE9F 73", b'\x01\x35\xe2\xa1\xe8\xfa\xf3\xfe\xa2\xf1\x7b\xbe\xfa\xd7\x10\xbe\xfa\xd7\x10\x92\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "6: 5434900075521908661 0x      123595425449AB2A4E 45", b'\x01\x36\xea\xfe\xd0\xf3\xd8\xb4\xd2\xec\x96\x01\x9c\xa9\xd9\x9a\x09\x9c\xa9\xd9\x9a\x09\x5a'),
TestCase("%s: %lld 0x%16u%08X %d", "7: 715267470600062067 0x      120413030347C591FF 114", b'\x01\x37\xe6\x91\x92\x88\xb2\xfe\x91\xed\x13\xfe\xc7\xac\xfc\x08\xfe\xc7\xac\xfc\x08\xe4\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "8: 3926011308434788247 0x      12666770164B7FF518 85", b'\x01\x38\xae\xbe\xe0\xf6\xfd\x9e\xff\xfb\x6c\xb0\xd4\xff\xb7\x09\xb0\xd4\xff\xb7\x09\xaa\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "9: 1478056893002169192 0x       7358327362BDBEAA0 35", b'\x01\x39\xd0\xed\xb1\x93\xb8\xba\x8e\x83\x29\xc0\xaa\xdf\xbd\x05\xc0\xaa\xdf\xbd\x05\x46'),
TestCase("%s: %lld 0x%16u%08X %d", "10: 7128491551588143718 0x      1717398262665D6AF6 94", b'\x02\x31\x30\xcc\xc9\xc6\xcc\x87\xd3\xbe\xed\xc5\x01\xec\xab\xeb\xe5\x0c\xec\xab\xeb\xe5\x0c\xbc\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "11: 193231861624509923 0x       4552840211B231535 41", b'\x02\x31\x31\xc6\xd7\xd4\xf6\xd6\xd6\xbf\xae\x05\xea\xd4\x98\xb2\x03\xea\xd4\x98\xb2\x03\x52'),
TestCase("%s: %lld 0x%16u%08X %d", "12: 4888125773563526975 0x      1378744602522DF91A 110", b'\x02\x31\x32\xfe\xfc\xfb\xea\xc3\x9f\x8e\xd6\x87\x01\xb4\xe4\xef\xa2\x0a\xb4\xe4\xef\xa2\x0a\xdc\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "13: 7673779374634366645 0x        1131769900ACB1C3 60", b'\x02\x31\x33\xea\xda\xe7\xdc\xe1\xeb\xde\xfe\xd4\x01\x86\xc7\xe5\x0a\x86\xc7\xe5\x0a\x78'),
TestCase("%s: %lld 0x%16u%08X %d", "14: 5854341954344571365 0x      108816167440DC078A 107", b'\x02\x31\x34\xca\xc7\xfe\xe5\xac\xbf\xe6\xbe\xa2\x01\x94\x9e\xe0\x8d\x08\x94\x9e\xe0\x8d\x08\xd6\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "15: 2326184191199164007 0x       8137466533080C9DD 82", b'\x02\x31\x35\xce\xd9\xf1\xe8\xcf\x8c\xa2\xc8\x40\xba\xa7\x86\x88\x06\xba\xa7\x86\x88\x06\xa4\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "16: 1424330851786829530 0x      1208787250480CA132 57", b'\x02\x31\x36\xb4\xbb\x91\xf6\x9f\xd7\x9e\xc4\x27\xe4\x84\xe5\x80\x09\xe4\x84\xe5\x80\x09\x72'),
TestCase("%s: %lld 0x%16u%08X %d", "17: 6389735809259880362 0x      18144454646C263D98 42", b'\x02\x31\x37\xd4\xfe\xb9\xf8\xa7\xb7\xf3\xac\xb1\x01\xb0\xf6\xb1\xc2\x0d\xb0\xf6\xb1\xc2\x0d\x54'),
TestCase("%s: %lld 0x%16u%08X %d", "18: 4564825427452770815 0x       2195709200D1662E8 62", b'\x02\x31\x38\xfe\xe7\xf1\x8f\xce\xa2\xc2\xd9\x7e\xd0\x8b\xb3\xd1\x01\xd0\x8b\xb3\xd1\x01\x7c'),
TestCase("%s: %lld 0x%16u%08X %d", "19: 1621021906259841134 0x      177653957669E3D7B8 93", b'\x02\x31\x39\xdc\xc1\xf4\xfb\xb9\xb5\x83\xff\x2c\xf0\xde\x9e\x9e\x0d\xf0\xde\x9e\x9e\x0d\xba\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "20: 8025284571884195522 0x      13595901875109B32B 94", b'\x02\x32\x30\x84\xbb\xa4\x89\x8c\xf3\xc4\xdf\xde\x01\xd6\xcc\xcd\x90\x0a\xd6\xcc\xcd\x90\x0a\xbc\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "21: 1310759272316304459 0x       85298242232D77A96 119", b'\x02\x32\x31\x96\xf1\xb3\xc7\xa1\xa7\xe0\xb0\x24\xac\xea\xbb\xad\x06\xac\xea\xbb\xad\x06\xee\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "22: 3661335273992329249 0x       825503981313430ED 105", b'\x02\x32\x32\xc2\xe0\xdc\x9e\x8f\xc2\xd6\xcf\x65\xda\xc3\xa1\x93\x06\xda\xc3\xa1\x93\x06\xd2\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "23: 4908269103466540013 0x      20984305627D138262 115", b'\x02\x32\x33\xda\xaf\xaf\xe2\xd2\xaf\xd6\x9d\x88\x01\xc4\x89\x9c\xd1\x0f\xc4\x89\x9c\xd1\x0f\xe6\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "24: 6541851858139706195 0x      148818392458B3E274 57", b'\x02\x32\x34\xa6\xcd\xab\x9a\xda\xe6\xa9\xc9\xb5\x01\xe8\x89\x9f\x8b\x0b\xe8\x89\x9f\x8b\x0b\x72'),
TestCase("%s: %lld 0x%16u%08X %d", "25: 4510904210489015127 0x      1191906481470B0CB1 71", b'\x02\x32\x35\xae\xed\x97\xa0\xd9\xde\xf9\x99\x7d\xe2\xb2\xd8\xf0\x08\xe2\xb2\xd8\xf0\x08\x8e\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "26: 1751202991906984173 0x      10412118623E0FA1D6 115", b'\x02\x32\x36\xda\xc3\xbc\xe3\xf8\xf5\xc2\xcd\x30\xac\x87\xfd\xe0\x07\xac\x87\xfd\xe0\x07\xe6\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "27: 7912743439818658557 0x      15466272805C2FA8D0 112", b'\x02\x32\x37\xfa\xcb\x8c\x93\x85\x8f\xdb\xcf\xdb\x01\xa0\xa3\xfd\xc2\x0b\xa0\xa3\xfd\xc2\x0b\xe0\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "28: 7865046769076850396 0x       95679371239078370 56", b'\x02\x32\x38\xb8\xbb\xc6\xca\xb3\x97\xa1\xa6\xda\x01\xe0\x8d\xbc\x90\x07\xe0\x8d\xbc\x90\x07\x70'),
TestCase("%s: %lld 0x%16u%08X %d", "29: 436719658465345699 0x       5945969062370D42A 43", b'\x02\x32\x39\xc6\x82\x8e\xd4\xe5\x8d\xc5\x8f\x0c\xd4\xd0\x86\xb7\x04\xd4\xd0\x86\xb7\x04\x56'),
TestCase("%s: %lld 0x%16u%08X %d", "30: 6212224561138197241 0x        1234914600BC6EDA 87", b'\x02\x33\x30\xf2\x8b\xcb\xf9\xe2\xd4\xa0\xb6\xac\x01\xb4\xbb\xe3\x0b\xb4\xbb\xe3\x0b\xae\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "31: 5419660422277913790 0x      177818160669FCE5E6 39", b'\x02\x33\x31\xfc\xf2\xf2\x91\x90\x9c\xc0\xb6\x96\x01\xcc\x97\xe7\x9f\x0d\xcc\x97\xe7\x9f\x0d\x4e'),
TestCase("%s: %lld 0x%16u%08X %d", "32: 1955771002711010609 0x      175837101468CE9CC6 114", b'\x02\x33\x32\xe2\xb4\xcb\xe9\xac\xd7\xa5\xa4\x36\x8c\xf3\xf4\x8c\x0d\x8c\xf3\xf4\x8c\x0d\xe4\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "33: 4550116504720438569 0x       1763101400A82477C 115", b'\x02\x33\x33\xd2\xd4\x87\xe8\xcf\xb6\xa1\xa5\x7e\xf8\x9d\x92\xa8\x01\xf8\x9d\x92\xa8\x01\xe6\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "34: 4684454901623556905 0x       4891671541D281932 106", b'\x02\x33\x34\xd2\xac\xe0\x99\xbd\xba\xc3\x82\x82\x01\xe4\xe4\xc0\xd2\x03\xe4\xe4\xc0\xd2\x03\xd4\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "35: 6234369280162760629 0x       39351496417748FD4 46", b'\x02\x33\x35\xea\x9e\xac\xeb\x88\xf5\xf6\x84\xad\x01\xa8\xbf\xa4\xf7\x02\xa8\xbf\xa4\xf7\x02\x5c'),
TestCase("%s: %lld 0x%16u%08X %d", "36: 8944940508995398022 0x      137633313452092D4E 45", b'\x02\x33\x36\x8c\xa6\xe1\xfa\x84\x80\xe8\xa2\xf8\x01\x9c\xb5\xc9\xa0\x0a\x9c\xb5\xc9\xa0\x0a\x5a'),
TestCase("%s: %lld 0x%16u%08X %d", "37: 4077388965675931531 0x       2899199101147D3A6 47", b'\x02\x33\x37\x96\xde\xb0\xe3\xa9\xea\xe5\x95\x71\xcc\xce\xbe\x94\x02\xcc\xce\xbe\x94\x02\x5e'),
TestCase("%s: %lld 0x%16u%08X %d", "38: 8856210144434134086 0x      1990062769769DF2B1 83", b'\x02\x33\x38\x8c\xf1\xa8\xb3\x88\x8d\xca\xe7\xf5\x01\xe2\xca\xef\xe9\x0e\xe2\xca\xef\xe9\x0e\xa6\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "39: 6269182192420305924 0x      15904663025ECC96FE 114", b'\x02\x33\x39\x88\xf0\xd5\xb6\xa1\xff\xcd\x80\xae\x01\xfc\xdb\xe4\xec\x0b\xfc\xdb\xe4\xec\x0b\xe4\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "40: 3168030316008523010 0x       560637674216AA6EA 54", b'\x02\x34\x30\x84\x94\xda\xf5\xb2\xb2\x8d\xf7\x57\xd4\x9b\xd5\x96\x04\xd4\x9b\xd5\x96\x04\x6c'),
TestCase("%s: %lld 0x%16u%08X %d", "41: 7828361129715530032 0x      120199790547A50851 125", b'\x02\x34\x31\xe0\xe4\xdb\xe2\x92\xbe\xf6\xa3\xd9\x01\xa2\xa1\xa8\xfa\x08\xa2\xa1\xa8\xfa\x08\xfa\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "42: 4684430121285811332 0x      1645956019621B4BB3 49", b'\x02\x34\x32\x88\xf2\x8b\xa6\x89\x98\xb8\x82\x82\x01\xe6\xae\xda\xa1\x0c\xe6\xae\xda\xa1\x0c\x62'),
TestCase("%s: %lld 0x%16u%08X %d", "43: 1094908319066476988 0x      200784098877AD38DC 34", b'\x02\x34\x33\xf8\xc6\x9e\xb9\x95\xd4\xf2\xb1\x1e\xb8\xe3\xe9\xfa\x0e\xb8\xe3\xe9\xfa\x0e\x44'),
TestCase("%s: %lld 0x%16u%08X %d", "44: 4188361875415362989 0x      193392125773454BE9 109", b'\x02\x34\x34\xda\xb6\xdf\xee\xe9\xbb\x86\xa0\x74\xd2\xaf\xaa\xb4\x0e\xd2\xaf\xaa\xb4\x0e\xda\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "45: 6350883509347762576 0x      147404369957DC1F33 76", b'\x02\x34\x35\xa0\x86\xfa\x88\xe8\xb9\xef\xa2\xb0\x01\xe6\xfc\xe0\xfd\x0a\xe6\xfc\xe0\xfd\x0a\x98\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "46: 3843711385867305612 0x      17834016666A4C8CC2 61", b'\x02\x34\x36\x98\x8a\xf6\xdb\xff\xc8\xcd\xd7\x6a\x84\xb3\xe4\xa4\x0d\x84\xb3\xe4\xa4\x0d\x7a'),
TestCase("%s: %lld 0x%16u%08X %d", "47: 5535789636778214509 0x      1184586398469B5A9E 84", b'\x02\x34\x37\xda\x91\xa2\xb7\x88\xd6\x89\xd3\x99\x01\xbc\xea\xda\xe9\x08\xbc\xea\xda\xe9\x08\xa8\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "48: 8891437578007474517 0x       1695359970A1AE9FD 111", b'\x02\x34\x38\xaa\xc5\x8f\xbb\xc9\xd7\xdd\xe4\xf6\x01\xfa\xa7\xd7\xa1\x01\xfa\xa7\xd7\xa1\x01\xde\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "49: 2483479174720276235 0x      14806493005840EA54 82", b'\x02\x34\x39\x96\x9c\xc2\x84\xd8\xc9\x8b\xf7\x44\xa8\xa9\x87\x84\x0b\xa8\xa9\x87\x84\x0b\xa4\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "50: 6416832625845083020 0x      13297388064F423436 87", b'\x02\x35\x30\x98\xee\x90\xea\xcf\xd1\x95\x8d\xb2\x01\xec\xd0\x91\xf4\x09\xec\xd0\x91\xf4\x09\xae\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "51: 3612059979445064775 0x      20936993057CCB50E9 117", b'\x02\x35\x31\x8e\xd1\xd2\xe3\xbd\xda\xce\xa0\x64\xd2\xc3\xda\xcc\x0f\xd2\xc3\xda\xcc\x0f\xea\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "52: 8599514281591661754 0x        1468170900E0066D 118", b'\x02\x35\x32\xf4\x92\xdb\xb2\xa9\xab\xce\xd7\xee\x01\xda\x99\x80\x0e\xda\x99\x80\x0e\xec\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "53: 1367741239369008397 0x         531248300510FE3 73", b'\x02\x35\x33\x9a\x94\xf0\xd3\xa3\xda\x98\xfb\x25\xc6\xbf\x88\x05\xc6\xbf\x88\x05\x92\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "54: 5473904087316166353 0x       5067733201E34BF48 68", b'\x02\x35\x34\xa2\xdb\xcf\xb0\xfe\xb0\x9b\xf7\x97\x01\x90\xfd\xa5\xe3\x03\x90\xfd\xa5\xe3\x03\x88\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "55: 1822527202856628083 0x      15610026845D0B02BC 58", b'\x02\x35\x35\xe6\xbd\x8b\xfc\xb6\xb5\xf5\xca\x32\xf8\x8a\xd8\xd0\x0b\xf8\x8a\xd8\xd0\x0b\x74'),
TestCase("%s: %lld 0x%16u%08X %d", "56: 3032341809633898873 0x      10226365813CF43225 113", b'\x02\x35\x36\xf2\xc5\xd9\x8c\xea\xb3\x85\x95\x54\xca\xc8\xa1\xcf\x07\xca\xc8\xa1\xcf\x07\xe2\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "57: 6856757614633255152 0x        8231254204E7FD5E 91", b'\x02\x35\x37\xe0\x83\xdc\xb2\x99\xae\x8c\xa8\xbe\x01\xbc\xf5\xbf\x4e\xbc\xf5\xbf\x4e\xb6\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "58: 3224702228554841730 0x      189119246370B94E8F 92", b'\x02\x35\x38\x84\xfa\xdf\xf6\xee\xe5\xb8\xc0\x59\x9e\xba\xca\x8b\x0e\x9e\xba\xca\x8b\x0e\xb8\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "59: 3988658283410987938 0x      176694389369516C95 34", b'\x02\x35\x39\xc4\xee\x8c\x92\xee\xe4\xc7\xda\x6e\xaa\xb2\x8b\x95\x0d\xaa\xb2\x8b\x95\x0d\x44'),
TestCase("%s: %lld 0x%16u%08X %d", "60: 72920210115635164 0x      1901935881715D3D09 71", b'\x02\x36\x30\xb8\x9f\x9d\xce\xee\xa2\x88\x83\x02\x92\xf4\xe9\x95\x0e\x92\xf4\xe9\x95\x0e\x8e\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "61: 4655403017017936000 0x      19053934447191FF24 48", b'\x02\x36\x31\x80\xa2\x96\xba\x9d\x98\xa8\x9b\x81\x01\xc8\xfc\x8f\x99\x0e\xc8\xfc\x8f\x99\x0e\x60'),
TestCase("%s: %lld 0x%16u%08X %d", "62: 288952216557681443 0x       39039797517450017 85", b'\x02\x36\x32\xc6\xec\xdb\x8f\xd2\xa0\xc8\x82\x08\xae\x80\xa8\xf4\x02\xae\x80\xa8\xf4\x02\xaa\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "63: 3219359012813218523 0x      21243024217E9E4855 51", b'\x02\x36\x33\xb6\x8b\xf9\xb2\xe3\xfd\xba\xad\x59\xaa\xa1\xf2\xe9\x0f\xaa\xa1\xf2\xe9\x0f\x66'),
TestCase("%s: %lld 0x%16u%08X %d", "64: 7496923004744506260 0x       65433043327004A41 39", b'\x02\x36\x34\xa8\xee\x80\xe4\x93\xf0\xb5\x8a\xd0\x01\x82\xa9\x82\xf0\x04\x82\xa9\x82\xf0\x04\x4e'),
TestCase("%s: %lld 0x%16u%08X %d", "65: 5886875793686089828 0x       2428972020E7A5132 73", b'\x02\x36\x35\xc8\xc1\x8a\xf8\x84\x96\xb1\xb2\xa3\x01\xe4\xc4\xd2\xe7\x01\xe4\xc4\xd2\xe7\x01\x92\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "66: 8352418169916257811 0x       157093077095D0CD5 107", b'\x02\x36\x36\xa6\xd8\x83\x96\xd2\x84\xe0\xe9\xe7\x01\xaa\xb3\xe8\x95\x01\xaa\xb3\xe8\x95\x01\xd6\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "67: 6425607598961991251 0x      142445717254E77DD4 102", b'\x02\x36\x37\xa6\xf9\xf0\xa2\xa4\x84\xac\xac\xb2\x01\xa8\xf7\xbb\xce\x0a\xa8\xf7\xbb\xce\x0a\xcc\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "68: 2394571431170796410 0x      21402538797F91AEB7 105", b'\x02\x36\x38\xf4\xad\xdf\x83\xf3\x81\x9d\xbb\x42\xee\xba\x8d\xf9\x0f\xee\xba\x8d\xf9\x0f\xd2\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "69: 891164515808164858 0x      10639639773F6ACD49 125", b'\x02\x36\x39\xf4\xef\xed\x92\xfa\xd9\x86\xde\x18\x92\xb5\xd6\xf6\x07\x92\xb5\xd6\xf6\x07\xfa\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "70: 4245075167591901055 0x      21000887517D2CCFAF 64", b'\x02\x37\x30\xfe\x9d\xad\x92\xf4\xd7\xc4\xe9\x75\xde\xbe\xe6\xd2\x0f\xde\xbe\xe6\xd2\x0f\x80\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "71: 979687222629424543 0x       958033112391A6CD8 45", b'\x02\x37\x31\xbe\xf6\x86\xfd\xd3\x95\xc6\x98\x1b\xb0\xb3\xd3\x91\x07\xb0\xb3\xd3\x91\x07\x5a'),
TestCase("%s: %lld 0x%16u%08X %d", "72: 2602113737417537288 0x       93725236837DD5610 105", b'\x02\x37\x32\x90\xdc\xfd\xfe\x8a\xaa\xc8\x9c\x48\xa0\xd8\xea\xfd\x06\xa0\xd8\xea\xfd\x06\xd2\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "73: 3036291044299697402 0x       2492532650EDB4D91 53", b'\x02\x37\x33\xf4\xb3\xf7\xa2\xc5\xa7\x89\xa3\x54\xa2\xb6\xda\xed\x01\xa2\xb6\xda\xed\x01\x6a'),
TestCase("%s: %lld 0x%16u%08X %d", "74: 5631405388638357750 0x        1248216000BE7670 56", b'\x02\x37\x34\xec\xa3\x94\x80\xaa\xd7\xe2\xa6\x9c\x01\xe0\xd9\xf3\x0b\xe0\xd9\xf3\x0b\x70'),
TestCase("%s: %lld 0x%16u%08X %d", "75: 6477169593541844553 0x       41341392918A43229 54", b'\x02\x37\x35\x92\xf9\xae\xd0\xb0\xdb\xc3\xe3\xb3\x01\xd2\xc8\xa1\x8a\x03\xd2\xc8\xa1\x8a\x03\x6c'),
TestCase("%s: %lld 0x%16u%08X %d", "76: 720129488086281194 0x      15625894285D2338F4 83", b'\x02\x37\x36\xd4\xaf\xd5\x9a\x87\xfd\xb4\xfe\x13\xe8\xe3\x99\xd2\x0b\xe8\xe3\x99\xd2\x0b\xa6\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "77: 7513165068981918756 0x       694699741296846DD 57", b'\x02\x37\x37\xc8\xf0\xd2\xb8\xdc\xf4\x8f\xc4\xd0\x01\xba\x9b\xc2\x96\x05\xba\x9b\xc2\x96\x05\x72'),
TestCase("%s: %lld 0x%16u%08X %d", "78: 3737216259576487553 0x       5295090401F8FAAB0 121", b'\x02\x37\x38\x82\xfa\xf6\x8d\xe6\x98\xa1\xdd\x67\xe0\xaa\xfd\xf8\x03\xe0\xaa\xfd\xf8\x03\xf2\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "79: 3565198557459535882 0x       86912895033CDDAF6 125", b'\x02\x37\x39\x94\xe0\xe2\xb1\xdc\xcc\x90\xfa\x62\xec\xeb\xee\xbc\x06\xec\xeb\xee\xbc\x06\xfa\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "80: 5371965991102827603 0x       11276814506B8B491 120", b'\x02\x38\x30\xa6\xb1\xce\xd2\xec\xa6\x87\x8d\x95\x01\xa2\xd2\xc5\x6b\xa2\xd2\xc5\x6b\xf0\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "81: 5776656679787538668 0x      18268958606CE437F4 72", b'\x02\x38\x31\xd8\xa3\xfd\xc1\x9d\xa9\xe7\xaa\xa0\x01\xe8\xdf\xa1\xce\x0d\xe8\xdf\xa1\xce\x0d\x90\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "82: 749331093609658474 0x       96722711439A6B6EA 32", b'\x02\x38\x32\xd4\xe1\x91\xdc\x9a\xaa\x94\xe6\x14\xd4\xdb\xb5\x9a\x07\xd4\xdb\xb5\x9a\x07\x40'),
TestCase("%s: %lld 0x%16u%08X %d", "83: 8161063962699005564 0x       86834268433C1DB9C 80", b'\x02\x38\x33\xf8\xf9\xd3\xde\xea\x9b\xf6\xc1\xe2\x01\xb8\xee\x8e\xbc\x06\xb8\xee\x8e\xbc\x06\xa0\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "84: 3621720449882747425 0x       85086863932B7399F 122", b'\x02\x38\x34\xc2\xc8\xbb\xb0\xef\xe3\xf7\xc2\x64\xbe\xe6\xb9\xab\x06\xbe\xe6\xb9\xab\x06\xf4\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "85: 8747087227033699739 0x      18257513516CD2C137 101", b'\x02\x38\x35\xb6\x96\x9a\xab\xa5\xdf\xf2\xe3\xf2\x01\xee\x84\x96\xcd\x0d\xee\x84\x96\xcd\x0d\xca\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "86: 8253451662283365177 0x       7840661982EBBE696 79", b'\x02\x38\x36\xf2\xec\x8e\xd4\xdc\xa3\x93\x8a\xe5\x01\xac\x9a\xdf\xeb\x05\xac\x9a\xdf\xeb\x05\x9e\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "87: 134795648044988988 0x       5147834581EAEF8E2 105", b'\x02\x38\x37\xf8\xe8\xeb\xef\xaf\xfb\xf1\xde\x03\xc4\xe3\xf7\xea\x03\xc4\xe3\xf7\xea\x03\xd2\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "88: 421750780720578633 0x      137027843451ACCA22 65", b'\x02\x38\x38\x92\x81\xc0\xc9\xb7\x86\xae\xda\x0b\xc4\xa8\xe6\x9a\x0a\xc4\xa8\xe6\x9a\x0a\x82\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "89: 8457438023241447265 0x      200824394177B35EE5 47", b'\x02\x38\x39\xc2\xdd\x81\xd3\xd3\xc4\xed\xde\xea\x01\xca\xfb\x9a\xfb\x0e\xca\xfb\x9a\xfb\x0e\x5e'),
TestCase("%s: %lld 0x%16u%08X %d", "90: 4522738759120336903 0x       6219044132511821D 72", b'\x02\x39\x30\x8e\xe0\x91\xd4\x8b\xbc\xff\xc3\x7d\xba\x88\x8c\xd1\x04\xba\x88\x8c\xd1\x04\x90\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "91: 3110596655769706088 0x      167356506563C09389 68", b'\x02\x39\x31\xd0\xf9\xde\xaa\xb0\xcb\x87\xab\x56\x92\xce\x84\xbc\x0c\x92\xce\x84\xbc\x0c\x88\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "92: 6450021345187045785 0x       390795837174B123D 32", b'\x02\x39\x32\xb2\x86\xfd\x98\xac\x8f\x8a\x83\xb3\x01\xfa\xc8\xd8\xf4\x02\xfa\xc8\xd8\xf4\x02\x40'),
TestCase("%s: %lld 0x%16u%08X %d", "93: 8586083292869710126 0x      170638545665B56030 78", b'\x02\x39\x33\xdc\xc4\xd2\xb6\xf1\xd0\xf2\xa7\xee\x01\xe0\x80\xab\xdb\x0c\xe0\x80\xab\xdb\x0c\x9c\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "94: 88833738086841272 0x       90226635535C77DF3 82", b'\x02\x39\x34\xf0\xee\xe3\xab\x8d\xf4\xcc\xbb\x02\xe6\xf7\xbb\xdc\x06\xe6\xf7\xbb\xdc\x06\xa4\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "95: 349662797203771308 0x      18558755186E9E69BE 118", b'\x02\x39\x35\xd8\xbe\x80\xa8\xc4\x9d\xa0\xda\x09\xfc\xa6\xf3\xe9\x0d\xfc\xa6\xf3\xe9\x0d\xec\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "96: 163280929539230956 0x       40045642217DE7AE6 89", b'\x02\x39\x36\xd8\xb3\xc0\xbc\xfd\xc8\x8b\xc4\x04\xcc\xeb\xf3\xfd\x02\xcc\xeb\xf3\xfd\x02\xb2\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "97: 4371241115470848126 0x      1128261220433FE664 112", b'\x02\x39\x37\xfc\x81\xc7\xb3\xcf\xa8\xe2\xa9\x79\xc8\x99\xff\xb3\x08\xc8\x99\xff\xb3\x08\xe0\x01'),
TestCase("%s: %lld 0x%16u%08X %d", "98: 428374782176628108 0x      17127620106616AC9A 60", b'\x02\x39\x38\x98\xb6\xfc\xa5\x88\xa6\xf2\xf1\x0b\xb4\xb2\xb5\xe1\x0c\xb4\xb2\xb5\xe1\x0c\x78'),
TestCase("%s: %lld 0x%16u%08X %d", "99: 7023621621475593673 0x       1965201350BB6A8C7 58", b'\x02\x39\x39\x92\xb7\xf2\x8c\xdd\xa9\xf5\xf8\xc2\x01\x8e\xa3\xb5\xbb\x01\x8e\xa3\xb5\xbb\x01\x74'),

)
